@@ -5,7 +5,7 @@ use std::collections::HashMap;
 
 use config::Config;
 use front_matter::InsertAnchor;
-use rendering::{render_content, render_shortcodes, RenderContext};
+use rendering::{render_content, RenderContext};
 use tera::Tera;
 
 static CONTENT: &str = r#"
@@ -85,12 +85,13 @@ fn bench_render_content_with_highlighting(b: &mut test::Bencher) {
     let mut tera = Tera::default();
     tera.add_raw_template("shortcodes/youtube.html", "{{id}}").unwrap();
     let permalinks_ctx = HashMap::new();
-    let config = Config::default();
+    let mut config = Config::default();
+    config.markdown.highlight_code = true;
     let current_page_permalink = "";
     let context = RenderContext::new(
         &tera,
         &config,
-        "",
+        &config.default_language,
         current_page_permalink,
         &permalinks_ctx,
         InsertAnchor::None,
@@ -109,7 +110,7 @@ fn bench_render_content_without_highlighting(b: &mut test::Bencher) {
     let context = RenderContext::new(
         &tera,
         &config,
-        "",
+        &config.default_language,
         current_page_permalink,
         &permalinks_ctx,
         InsertAnchor::None,
@@ -117,7 +118,6 @@ fn bench_render_content_without_highlighting(b: &mut test::Bencher) {
     b.iter(|| render_content(CONTENT, &context).unwrap());
 }
 
-#[bench]
 fn bench_render_content_no_shortcode(b: &mut test::Bencher) {
     let tera = Tera::default();
     let content2 = CONTENT.replace(r#"{{ youtube(id="my_youtube_id") }}"#, "");
@@ -128,7 +128,7 @@ fn bench_render_content_no_shortcode(b: &mut test::Bencher) {
     let context = RenderContext::new(
         &tera,
         &config,
-        "",
+        &config.default_language,
         current_page_permalink,
         &permalinks_ctx,
         InsertAnchor::None,
@@ -138,26 +138,7 @@ fn bench_render_content_no_shortcode(b: &mut test::Bencher) {
 }
 
 #[bench]
-fn bench_render_shortcodes_one_present(b: &mut test::Bencher) {
-    let mut tera = Tera::default();
-    tera.add_raw_template("shortcodes/youtube.html", "{{id}}").unwrap();
-    let config = Config::default();
-    let permalinks_ctx = HashMap::new();
-    let current_page_permalink = "";
-    let context = RenderContext::new(
-        &tera,
-        &config,
-        "",
-        current_page_permalink,
-        &permalinks_ctx,
-        InsertAnchor::None,
-    );
-
-    b.iter(|| render_shortcodes(CONTENT, &context));
-}
-
-#[bench]
-fn bench_render_content_no_shortcode_with_emoji(b: &mut test::Bencher) {
+fn bench_render_content_with_emoji(b: &mut test::Bencher) {
     let tera = Tera::default();
     let content2 = CONTENT.replace(r#"{{ youtube(id="my_youtube_id") }}"#, "");
     let mut config = Config::default();
@@ -168,7 +149,7 @@ fn bench_render_content_no_shortcode_with_emoji(b: &mut test::Bencher) {
     let context = RenderContext::new(
         &tera,
         &config,
-        "",
+        &config.default_language,
         current_page_permalink,
         &permalinks_ctx,
         InsertAnchor::None,
